@@ -12,11 +12,12 @@
 #' @param main Main title for plot.
 #' @param ... Optional arguments which will be ignored.
 #' 
-#' @details The function will generate a panel of plots, one for each importance type.
+#' @details The function will generate a panel of plots, one for each 
+#'   importance type.
 #' 
 #' @author Eric Archer \email{eric.archer@@noaa.gov}
 #' 
-#' @import ggplot2 
+#' @importFrom ggplot2 ggplot aes geom_bar labs coord_flip theme scale_fill_manual
 #' @importFrom gridExtra grid.arrange
 #' @export
 #' 
@@ -28,12 +29,12 @@ plot.rp.importance <- function(x, alpha = 0.05, sig.only = FALSE,
     type <- unique(gsub(".pval", "", type))
     not.found <- setdiff(type, colnames(x))
     if(length(not.found) > 0) {
-      stop(paste("the following columns in 'type' can't be found in 'x':",
-                 paste(not.found, collapse = ", ")
-      ))
+      not.found <- paste(not.found, collapse = ", ")
+      stop(paste("the following columns in 'type' can't be found in 'x':", not.found))
     }
     lapply(match(type, colnames(x)), function(i) c(i, i + 1))
   }
+  
   imp.list <- lapply(cols, function(i) {
     imp.df <- as.data.frame(x[, i])
     colnames(imp.df) <- c("imp", "pval")
@@ -44,10 +45,11 @@ plot.rp.importance <- function(x, alpha = 0.05, sig.only = FALSE,
     imp.df <- imp.df[order(imp.df$imp, decreasing = TRUE), ]
     if(sig.only) imp.df <- imp.df[as.logical(imp.df$is.sig), ]
     if(!is.null(n) & is.numeric(n)) imp.df <- imp.df[1:min(n, nrow(imp.df)), ]
-    with(imp.df, ggplot(imp.df, aes(reorder(pred, imp), imp)) + 
+    with(imp.df, 
+         ggplot(imp.df, aes(reorder(pred, imp), imp)) + 
            geom_bar(aes(fill = is.sig), stat = "identity") +
-           labs(title = colnames(x)[i], x = "", y = "Importance") + coord_flip() +
-           theme(legend.position = "none") +
+           labs(title = colnames(x)[i], x = "", y = "Importance") + 
+           coord_flip() + theme(legend.position = "none") +
            scale_fill_manual(values = c("FALSE" = "black", "TRUE" = "red"))
     )
   })
